<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Indikator-Stil</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Design-Modus</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Effizienzmodus</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klassischer Modus</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Zentrierter Modus</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Angezeigt lassen</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Ausgeblendet lassen</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Schlaues Ausblenden</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Dock-Einstellungen</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>